==> dapware-ram-2.2.1.1000-sources.jar: com/digiwin/dap/middle/ram/domain/RouteVO.java <==
package com.digiwin.dap.middle.ram.domain;

import com.digiwin.dap.middle.ram.domain.page.Page;
import org.springframework.util.StringUtils;

import java.time.LocalDateTime;

/**
 * 路由清单
 *
 * @author Xiao
 * @date 2021/8/16 16:42
 */
public class RouteVO extends Page {

    private Long sid;
    private String app;
    private String method;
    private String path;
    private Boolean effect;
    private LocalDateTime createDate;
    private LocalDateTime attachDate;
    private Integer useCount;

    public Long getSid() {
        return sid;
    }

    public void setSid(Long sid) {
        this.sid = sid;
    }

    public String getApp() {
        return app;
    }

    public void setApp(String app) {
        this.app = app;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public Boolean getEffect() {
        return effect;
    }

    public void setEffect(Boolean effect) {
        this.effect = effect;
    }

    public LocalDateTime getCreateDate() {
        return createDate;
    }

    public void setCreateDate(LocalDateTime createDate) {
        this.createDate = createDate;
    }

    public LocalDateTime getAttachDate() {
        return attachDate;
    }

    public void setAttachDate(LocalDateTime attachDate) {
        this.attachDate = attachDate;
    }

    public Integer getUseCount() {
        return useCount;
    }

    public void setUseCount(Integer useCount) {
        this.useCount = useCount;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder("{");
        if (StringUtils.hasText(method)) {
            builder.append(method).append(" ");
        }
        builder.append(path);
        builder.append('}');
        return builder.toString();
    }
}

==> dapware-ram-2.7.0-sources.jar: com/digiwin/dap/middle/ram/domain/RouteVO.java <==
package com.digiwin.dap.middle.ram.domain;

import org.springframework.util.StringUtils;

import java.time.LocalDateTime;

/**
 * 路由清单
 *
 * @author fobgochod
 * @date 2021/8/16 16:42
 */
public class RouteVO {

    private Long sid;
    private String app;
    private String name;
    private String method;
    private String path;
    private String tableName;
    private String remark;
    private Boolean effect;
    private LocalDateTime createDate;
    private LocalDateTime attachDate;
    private Integer useCount;

    public Long getSid() {
        return sid;
    }

    public void setSid(Long sid) {
        this.sid = sid;
    }

    public String getApp() {
        return app;
    }

    public void setApp(String app) {
        this.app = app;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getMethod() {
        return method;
    }

    public void setMethod(String method) {
        this.method = method;
    }

    public String getPath() {
        return path;
    }

    public void setPath(String path) {
        this.path = path;
    }

    public String getTableName() {
        return tableName;
    }

    public void setTableName(String tableName) {
        this.tableName = tableName;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Boolean getEffect() {
        return effect;
    }

    public void setEffect(Boolean effect) {
        this.effect = effect;
    }

    public LocalDateTime getCreateDate() {
        return createDate;
    }

    public void setCreateDate(LocalDateTime createDate) {
        this.createDate = createDate;
    }

    public LocalDateTime getAttachDate() {
        return attachDate;
    }

    public void setAttachDate(LocalDateTime attachDate) {
        this.attachDate = attachDate;
    }

    public Integer getUseCount() {
        return useCount;
    }

    public void setUseCount(Integer useCount) {
        this.useCount = useCount;
    }

    @Override
    public String toString() {
        StringBuilder builder = new StringBuilder("{");
        if (StringUtils.hasText(method)) {
            builder.append(method).append(" ");
        }
        builder.append(path);
        builder.append('}');
        return builder.toString();
    }
}
